%define anolis_release 1
Name:           pcsc-lite
Version:        1.9.5
Release:        %{anolis_release}%{?dist}
Summary:        PC/SC Lite smart card framework and applications

License:        BSD
URL:            https://pcsclite.apdu.fr/
Source0:        https://pcsclite.apdu.fr/files/%{name}-%{version}.tar.bz2

BuildRequires: make
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  systemd-devel
BuildRequires:  /usr/bin/pod2man
BuildRequires:  polkit-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
BuildRequires:  libtool
BuildRequires:  gnupg2
BuildRequires:  gcc
BuildRequires:  python3-devel
BuildRequires:  /usr/bin/pathfix.py

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires:       pcsc-ifd-handler
Requires:       %{name}-libs = %{version}-%{release}
Requires:       polkit
Requires:       python3
Recommends:     pcsc-lite-ccid
# This is bundled in upstream withou simple way to remove
Provides:       bundled(simclist) = 1.6


%description
The purpose of PC/SC Lite is to provide a Windows(R) SCard interface
in a very small form factor for communicating to smartcards and
readers.  PC/SC Lite uses the same winscard API as used under
Windows(R).  This package includes the PC/SC Lite daemon, a resource
manager that coordinates communications with smart card readers and
smart cards that are connected to the system, as well as other command
line tools.

%package        libs
Summary:        PC/SC Lite libraries

%description    libs
PC/SC Lite libraries.

%package        devel
Summary:        PC/SC Lite development files
Requires:       %{name}-libs = %{version}-%{release}

%description    devel
PC/SC Lite development files.

%package        doc
Summary:        PC/SC Lite developer documentation
BuildArch:      noarch
Requires:       %{name}-libs = %{version}-%{release}

%description    doc
%{summary}.


%prep
%setup -q

# Convert to utf-8
for file in ChangeLog; do
    iconv -f ISO-8859-1 -t UTF-8 -o $file.new $file && \
    touch -r $file $file.new && \
    mv $file.new $file
done


%build
%configure \
  --disable-static \
  --enable-polkit \
  --enable-usbdropdir=%{_libdir}/pcsc/drivers
%make_build
doxygen doc/doxygen.conf ; rm -f doc/api/*.{map,md5}
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" src/spy/pcsc-spy


%install
%make_install

# Create empty directories
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/reader.conf.d
mkdir -p $RPM_BUILD_ROOT%{_libdir}/pcsc/drivers
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/run/pcscd

rm $RPM_BUILD_ROOT%{_libdir}/*.la


%post
%systemd_post pcscd.socket pcscd.service
# If install, test if pcscd socket is enabled.
# If enabled, then attempt to start it. This will silently fail
# in chroots or other environments where services aren't expected
# to be started.
if [ $1 -eq 1 ] ; then
   if systemctl -q is-enabled pcscd.socket > /dev/null 2>&1 ; then
      systemctl start pcscd.socket > /dev/null 2>&1 || :
   fi
fi

%preun
%systemd_preun pcscd.socket pcscd.service

%postun
%systemd_postun_with_restart pcscd.socket pcscd.service

%ldconfig_scriptlets libs


%files
%doc AUTHORS ChangeLog HELP README SECURITY TODO
%doc doc/README.polkit
%dir %{_sysconfdir}/reader.conf.d/
%{_unitdir}/pcscd.service
%{_unitdir}/pcscd.socket
%{_sbindir}/pcscd
%dir %{_libdir}/pcsc/
%dir %{_libdir}/pcsc/drivers/
%{_mandir}/man5/reader.conf.5*
%{_mandir}/man8/pcscd.8*
%{_datadir}/polkit-1/actions/org.debian.pcsc-lite.policy
%ghost %dir %{_localstatedir}/run/pcscd/

%files libs
%license COPYING
%{_libdir}/libpcsclite.so.*

%files devel
%{_bindir}/pcsc-spy
%{_includedir}/PCSC/
%{_libdir}/libpcsclite.so
%{_libdir}/libpcscspy.so*
%{_libdir}/pkgconfig/libpcsclite.pc
%{_mandir}/man1/pcsc-spy.1*

%files doc
%doc doc/api/ doc/example/pcsc_demo.c


%changelog
* Wed Mar 23 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.9.5-1
- init from upstream
